# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 14.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.



# The name this table is to be known by, with the format of the mappings in
# the main body of the table, and what all code points missing from this file
# map to.
$Unicode::UCD::SwashInfo{'ToInSC'}{'format'} = 's'; # string
$Unicode::UCD::SwashInfo{'ToInSC'}{'missing'} = 'Other';

return <<'END';
2D		Consonant_Placeholder
30	39	Number
A0		Consonant_Placeholder
B2	B3	Syllable_Modifier
D7		Consonant_Placeholder
900	902	Bindu
903		Visarga
904	914	Vowel_Independent
915	939	Consonant
93A	93B	Vowel_Dependent
93C		Nukta
93D		Avagraha
93E	94C	Vowel_Dependent
94D		Virama
94E	94F	Vowel_Dependent
951	952	Cantillation_Mark
955	957	Vowel_Dependent
958	95F	Consonant
960	961	Vowel_Independent
962	963	Vowel_Dependent
966	96F	Number
972	977	Vowel_Independent
978	97F	Consonant
980		Consonant_Placeholder
981	982	Bindu
983		Visarga
985	98C	Vowel_Independent
98F	990	Vowel_Independent
993	994	Vowel_Independent
995	9A8	Consonant
9AA	9B0	Consonant
9B2		Consonant
9B6	9B9	Consonant
9BC		Nukta
9BD		Avagraha
9BE	9C4	Vowel_Dependent
9C7	9C8	Vowel_Dependent
9CB	9CC	Vowel_Dependent
9CD		Virama
9CE		Consonant_Dead
9D7		Vowel_Dependent
9DC	9DD	Consonant
9DF		Consonant
9E0	9E1	Vowel_Independent
9E2	9E3	Vowel_Dependent
9E6	9EF	Number
9F0	9F1	Consonant
9FC		Bindu
9FE		Syllable_Modifier
A01	A02	Bindu
A03		Visarga
A05	A0A	Vowel_Independent
A0F	A10	Vowel_Independent
A13	A14	Vowel_Independent
A15	A28	Consonant
A2A	A30	Consonant
A32	A33	Consonant
A35	A36	Consonant
A38	A39	Consonant
A3C		Nukta
A3E	A42	Vowel_Dependent
A47	A48	Vowel_Dependent
A4B	A4C	Vowel_Dependent
A4D		Virama
A51		Cantillation_Mark
A59	A5C	Consonant
A5E		Consonant
A66	A6F	Number
A70		Bindu
A71		Gemination_Mark
A72	A73	Consonant_Placeholder
A75		Consonant_Medial
A81	A82	Bindu
A83		Visarga
A85	A8D	Vowel_Independent
A8F	A91	Vowel_Independent
A93	A94	Vowel_Independent
A95	AA8	Consonant
AAA	AB0	Consonant
AB2	AB3	Consonant
AB5	AB9	Consonant
ABC		Nukta
ABD		Avagraha
ABE	AC5	Vowel_Dependent
AC7	AC9	Vowel_Dependent
ACB	ACC	Vowel_Dependent
ACD		Virama
AE0	AE1	Vowel_Independent
AE2	AE3	Vowel_Dependent
AE6	AEF	Number
AF9		Consonant
AFA	AFC	Cantillation_Mark
AFD	AFF	Nukta
B01	B02	Bindu
B03		Visarga
B05	B0C	Vowel_Independent
B0F	B10	Vowel_Independent
B13	B14	Vowel_Independent
B15	B28	Consonant
B2A	B30	Consonant
B32	B33	Consonant
B35	B39	Consonant
B3C		Nukta
B3D		Avagraha
B3E	B44	Vowel_Dependent
B47	B48	Vowel_Dependent
B4B	B4C	Vowel_Dependent
B4D		Virama
B55	B57	Vowel_Dependent
B5C	B5D	Consonant
B5F		Consonant
B60	B61	Vowel_Independent
B62	B63	Vowel_Dependent
B66	B6F	Number
B71		Consonant
B82		Bindu
B83		Modifying_Letter
B85	B8A	Vowel_Independent
B8E	B90	Vowel_Independent
B92	B94	Vowel_Independent
B95		Consonant
B99	B9A	Consonant
B9C		Consonant
B9E	B9F	Consonant
BA3	BA4	Consonant
BA8	BAA	Consonant
BAE	BB9	Consonant
BBE	BC2	Vowel_Dependent
BC6	BC8	Vowel_Dependent
BCA	BCC	Vowel_Dependent
BCD		Virama
BD7		Vowel_Dependent
BE6	BEF	Number
C00	C02	Bindu
C03		Visarga
C04		Bindu
C05	C0C	Vowel_Independent
C0E	C10	Vowel_Independent
C12	C14	Vowel_Independent
C15	C28	Consonant
C2A	C39	Consonant
C3C		Nukta
C3D		Avagraha
C3E	C44	Vowel_Dependent
C46	C48	Vowel_Dependent
C4A	C4C	Vowel_Dependent
C4D		Virama
C55	C56	Vowel_Dependent
C58	C5A	Consonant
C5D		Consonant_Dead
C60	C61	Vowel_Independent
C62	C63	Vowel_Dependent
C66	C6F	Number
C80	C82	Bindu
C83		Visarga
C85	C8C	Vowel_Independent
C8E	C90	Vowel_Independent
C92	C94	Vowel_Independent
C95	CA8	Consonant
CAA	CB3	Consonant
CB5	CB9	Consonant
CBC		Nukta
CBD		Avagraha
CBE	CC4	Vowel_Dependent
CC6	CC8	Vowel_Dependent
CCA	CCC	Vowel_Dependent
CCD		Virama
CD5	CD6	Vowel_Dependent
CDD		Consonant_Dead
CDE		Consonant
CE0	CE1	Vowel_Independent
CE2	CE3	Vowel_Dependent
CE6	CEF	Number
CF1	CF2	Consonant_With_Stacker
D00	D02	Bindu
D03		Visarga
D04		Bindu
D05	D0C	Vowel_Independent
D0E	D10	Vowel_Independent
D12	D14	Vowel_Independent
D15	D3A	Consonant
D3B	D3C	Pure_Killer
D3D		Avagraha
D3E	D44	Vowel_Dependent
D46	D48	Vowel_Dependent
D4A	D4C	Vowel_Dependent
D4D		Virama
D4E		Consonant_Preceding_Repha
D54	D56	Consonant_Dead
D57		Vowel_Dependent
D5F	D61	Vowel_Independent
D62	D63	Vowel_Dependent
D66	D6F	Number
D7A	D7F	Consonant_Dead
D81	D82	Bindu
D83		Visarga
D85	D96	Vowel_Independent
D9A	DB1	Consonant
DB3	DBB	Consonant
DBD		Consonant
DC0	DC6	Consonant
DCA		Virama
DCF	DD4	Vowel_Dependent
DD6		Vowel_Dependent
DD8	DDF	Vowel_Dependent
DE6	DEF	Number
DF2	DF3	Vowel_Dependent
E01	E2E	Consonant
E30	E39	Vowel_Dependent
E3A		Pure_Killer
E40	E45	Vowel_Dependent
E47		Vowel_Dependent
E48	E4B	Tone_Mark
E4C		Consonant_Killer
E4D		Bindu
E4E		Pure_Killer
E50	E59	Number
E81	E82	Consonant
E84		Consonant
E86	E8A	Consonant
E8C	EA3	Consonant
EA5		Consonant
EA7	EAE	Consonant
EB0	EB9	Vowel_Dependent
EBA		Pure_Killer
EBB		Vowel_Dependent
EBC	EBD	Consonant_Medial
EC0	EC4	Vowel_Dependent
EC8	ECB	Tone_Mark
ECD		Bindu
ED0	ED9	Number
EDC	EDF	Consonant
F20	F33	Number
F35		Syllable_Modifier
F37		Syllable_Modifier
F39		Nukta
F40	F47	Consonant
F49	F6C	Consonant
F71	F7D	Vowel_Dependent
F7E		Bindu
F7F		Visarga
F80	F81	Vowel_Dependent
F82	F83	Bindu
F84		Pure_Killer
F85		Avagraha
F88	F8C	Consonant_Head_Letter
F8D	F97	Consonant_Subjoined
F99	FBC	Consonant_Subjoined
FC6		Syllable_Modifier
1000	1020	Consonant
1021	102A	Vowel_Independent
102B	1035	Vowel_Dependent
1036		Bindu
1037		Tone_Mark
1038		Visarga
1039		Invisible_Stacker
103A		Pure_Killer
103B	103E	Consonant_Medial
103F		Consonant
1040	1049	Number
104B		Consonant_Placeholder
104E		Consonant_Placeholder
1050	1051	Consonant
1052	1055	Vowel_Independent
1056	1059	Vowel_Dependent
105A	105D	Consonant
105E	1060	Consonant_Medial
1061		Consonant
1062		Vowel_Dependent
1063	1064	Tone_Mark
1065	1066	Consonant
1067	1068	Vowel_Dependent
1069	106D	Tone_Mark
106E	1070	Consonant
1071	1074	Vowel_Dependent
1075	1081	Consonant
1082		Consonant_Medial
1083	1086	Vowel_Dependent
1087	108D	Tone_Mark
108E		Consonant
108F		Tone_Mark
1090	1099	Number
109A	109B	Tone_Mark
109C	109D	Vowel_Dependent
1700	1702	Vowel_Independent
1703	1711	Consonant
1712	1713	Vowel_Dependent
1714	1715	Pure_Killer
171F		Consonant
1720	1722	Vowel_Independent
1723	1731	Consonant
1732	1733	Vowel_Dependent
1734		Pure_Killer
1740	1742	Vowel_Independent
1743	1751	Consonant
1752	1753	Vowel_Dependent
1760	1762	Vowel_Independent
1763	176C	Consonant
176E	1770	Consonant
1772	1773	Vowel_Dependent
1780	17A2	Consonant
17A3	17B3	Vowel_Independent
17B6	17C5	Vowel_Dependent
17C6		Bindu
17C7		Visarga
17C8		Vowel_Dependent
17C9	17CA	Register_Shifter
17CB		Syllable_Modifier
17CC		Consonant_Succeeding_Repha
17CD		Consonant_Killer
17CE	17D0	Syllable_Modifier
17D1		Pure_Killer
17D2		Invisible_Stacker
17D3		Syllable_Modifier
17DC		Avagraha
17DD		Syllable_Modifier
17E0	17E9	Number
1900		Consonant_Placeholder
1901	191E	Consonant
1920	1928	Vowel_Dependent
1929	192B	Consonant_Subjoined
1930	1931	Consonant_Final
1932		Bindu
1933	1939	Consonant_Final
193A		Vowel_Dependent
193B		Syllable_Modifier
1946	194F	Number
1950	1962	Consonant
1963	196D	Vowel
1970	1974	Tone_Letter
1980	19AB	Consonant
19B0	19C0	Vowel_Dependent
19C1	19C7	Consonant_Final
19C8	19C9	Tone_Mark
19D0	19DA	Number
1A00	1A16	Consonant
1A17	1A1B	Vowel_Dependent
1A20	1A4C	Consonant
1A4D	1A52	Vowel_Independent
1A53	1A54	Consonant
1A55	1A56	Consonant_Medial
1A57		Consonant_Subjoined
1A58	1A59	Consonant_Final
1A5A		Consonant_Initial_Postfixed
1A5B	1A5E	Consonant_Subjoined
1A60		Invisible_Stacker
1A61	1A73	Vowel_Dependent
1A74		Bindu
1A75	1A79	Tone_Mark
1A7A		Pure_Killer
1A7B	1A7C	Syllable_Modifier
1A7F		Syllable_Modifier
1A80	1A89	Number
1A90	1A99	Number
1B00	1B02	Bindu
1B03		Consonant_Final
1B04		Visarga
1B05	1B12	Vowel_Independent
1B13	1B33	Consonant
1B34		Nukta
1B35	1B43	Vowel_Dependent
1B44		Virama
1B45	1B4C	Consonant
1B50	1B59	Number
1B80		Bindu
1B81		Consonant_Final
1B82		Visarga
1B83	1B89	Vowel_Independent
1B8A	1BA0	Consonant
1BA1	1BA3	Consonant_Subjoined
1BA4	1BA9	Vowel_Dependent
1BAA		Pure_Killer
1BAB		Invisible_Stacker
1BAC	1BAD	Consonant_Subjoined
1BAE	1BAF	Consonant
1BB0	1BB9	Number
1BBA		Avagraha
1BBB	1BBD	Consonant
1BBE	1BBF	Consonant_Final
1BC0	1BE3	Consonant
1BE4	1BE5	Vowel_Independent
1BE6		Nukta
1BE7	1BEF	Vowel_Dependent
1BF0	1BF1	Consonant_Final
1BF2	1BF3	Pure_Killer
1C00	1C23	Consonant
1C24	1C25	Consonant_Subjoined
1C26	1C2C	Vowel_Dependent
1C2D	1C33	Consonant_Final
1C34	1C35	Bindu
1C36		Syllable_Modifier
1C37		Nukta
1C40	1C49	Number
1C4D	1C4F	Consonant
1CD0	1CD2	Cantillation_Mark
1CD4	1CE1	Cantillation_Mark
1CF2	1CF3	Consonant_Dead
1CF4		Cantillation_Mark
1CF5	1CF6	Consonant_With_Stacker
1CF7	1CF9	Cantillation_Mark
1CFA		Consonant_Placeholder
1DFB		Syllable_Modifier
200C		Non_Joiner
200D		Joiner
2010	2014	Consonant_Placeholder
2074		Syllable_Modifier
2082	2084	Syllable_Modifier
20F0		Cantillation_Mark
25CC		Consonant_Placeholder
A800	A801	Vowel_Independent
A802		Vowel_Dependent
A803	A805	Vowel_Independent
A806		Virama
A807	A80A	Consonant
A80B		Bindu
A80C	A822	Consonant
A823	A827	Vowel_Dependent
A82C		Pure_Killer
A840	A85D	Consonant
A85E	A861	Vowel
A862	A865	Consonant
A866		Vowel
A867	A868	Consonant_Subjoined
A869	A870	Consonant
A871		Consonant_Subjoined
A872		Consonant
A873		Bindu
A880		Bindu
A881		Visarga
A882	A891	Vowel_Independent
A892	A8B3	Consonant
A8B4		Consonant_Medial
A8B5	A8C3	Vowel_Dependent
A8C4		Virama
A8C5		Bindu
A8D0	A8D9	Number
A8E0	A8F1	Cantillation_Mark
A8F2	A8F3	Bindu
A8FE		Vowel_Independent
A8FF		Vowel_Dependent
A900	A909	Number
A90A	A921	Consonant
A922	A92A	Vowel
A92B	A92D	Tone_Mark
A930	A946	Consonant
A947	A94E	Vowel_Dependent
A94F	A952	Consonant_Final
A953		Pure_Killer
A980	A981	Bindu
A982		Consonant_Final
A983		Visarga
A984	A988	Vowel_Independent
A989	A98B	Consonant
A98C	A98E	Vowel_Independent
A98F	A9B2	Consonant
A9B3		Nukta
A9B4	A9BC	Vowel_Dependent
A9BD	A9BF	Consonant_Medial
A9C0		Virama
A9D0	A9D9	Number
A9E0	A9E4	Consonant
A9E5		Vowel_Dependent
A9E7	A9EF	Consonant
A9F0	A9F9	Number
A9FA	A9FE	Consonant
AA00	AA05	Vowel_Independent
AA06	AA28	Consonant
AA29	AA32	Vowel_Dependent
AA33	AA36	Consonant_Medial
AA40	AA4D	Consonant_Final
AA50	AA59	Number
AA60	AA6F	Consonant
AA71	AA73	Consonant
AA74	AA76	Consonant_Placeholder
AA7A		Consonant
AA7B	AA7D	Tone_Mark
AA7E	AAAF	Consonant
AAB0	AABE	Vowel_Dependent
AABF		Tone_Mark
AAC0		Tone_Letter
AAC1		Tone_Mark
AAC2		Tone_Letter
AAE0	AAE1	Vowel_Independent
AAE2	AAEA	Consonant
AAEB	AAEF	Vowel_Dependent
AAF5		Visarga
AAF6		Invisible_Stacker
ABC0	ABCD	Consonant
ABCE	ABCF	Vowel_Independent
ABD0		Consonant
ABD1		Vowel_Independent
ABD2	ABDA	Consonant
ABDB	ABE2	Consonant_Final
ABE3	ABEA	Vowel_Dependent
ABEC		Tone_Mark
ABED		Pure_Killer
ABF0	ABF9	Number
10A00		Consonant
10A01	10A03	Vowel_Dependent
10A05	10A06	Vowel_Dependent
10A0C	10A0D	Vowel_Dependent
10A0E		Bindu
10A0F		Visarga
10A10	10A13	Consonant
10A15	10A17	Consonant
10A19	10A35	Consonant
10A38	10A3A	Nukta
10A3F		Invisible_Stacker
10A40	10A48	Number
11000	11001	Bindu
11002		Visarga
11003	11004	Consonant_With_Stacker
11005	11012	Vowel_Independent
11013	11037	Consonant
11038	11045	Vowel_Dependent
11046		Virama
11052	11065	Brahmi_Joining_Number
11066	1106F	Number
11070		Pure_Killer
11071	11072	Vowel_Independent
11073	11074	Vowel_Dependent
11075		Consonant
1107F		Number_Joiner
11080	11081	Bindu
11082		Visarga
11083	1108C	Vowel_Independent
1108D	110AF	Consonant
110B0	110B8	Vowel_Dependent
110B9		Virama
110BA		Nukta
110C2		Vowel_Dependent
11100	11101	Bindu
11102		Visarga
11103	11106	Vowel_Independent
11107	11126	Consonant
11127	11132	Vowel_Dependent
11133		Invisible_Stacker
11134		Pure_Killer
11136	1113F	Number
11144		Consonant
11145	11146	Vowel_Dependent
11147		Consonant
11150	11154	Vowel
11155	11172	Consonant
11173		Nukta
11180	11181	Bindu
11182		Visarga
11183	11190	Vowel_Independent
11191	111B2	Consonant
111B3	111BF	Vowel_Dependent
111C0		Virama
111C1		Avagraha
111C2	111C3	Consonant_Prefixed
111C9		Syllable_Modifier
111CA		Nukta
111CB	111CC	Vowel_Dependent
111CE		Vowel_Dependent
111CF		Bindu
111D0	111D9	Number
111E1	111F4	Number
11200	11207	Vowel_Independent
11208	11211	Consonant
11213	1122B	Consonant
1122C	11233	Vowel_Dependent
11234		Bindu
11235		Virama
11236		Nukta
11237		Gemination_Mark
1123E		Cantillation_Mark
11280	11283	Vowel_Independent
11284	11286	Consonant
11288		Consonant
1128A	1128D	Consonant
1128F	1129D	Consonant
1129F	112A8	Consonant
112B0	112B9	Vowel_Independent
112BA	112DE	Consonant
112DF		Bindu
112E0	112E8	Vowel_Dependent
112E9		Nukta
112EA		Pure_Killer
112F0	112F9	Number
11300	11302	Bindu
11303		Visarga
11305	1130C	Vowel_Independent
1130F	11310	Vowel_Independent
11313	11314	Vowel_Independent
11315	11328	Consonant
1132A	11330	Consonant
11332	11333	Consonant
11335	11339	Consonant
1133B	1133C	Nukta
1133D		Avagraha
1133E	11344	Vowel_Dependent
11347	11348	Vowel_Dependent
1134B	1134C	Vowel_Dependent
1134D		Virama
11357		Vowel_Dependent
1135E	1135F	Bindu
11360	11361	Vowel_Independent
11362	11363	Vowel_Dependent
11366	1136C	Cantillation_Mark
11370	11374	Cantillation_Mark
11400	1140D	Vowel_Independent
1140E	11434	Consonant
11435	11441	Vowel_Dependent
11442		Virama
11443	11444	Bindu
11445		Visarga
11446		Nukta
11447		Avagraha
11450	11459	Number
1145E		Syllable_Modifier
1145F		Bindu
11460	11461	Consonant_With_Stacker
11481	1148E	Vowel_Independent
1148F	114AF	Consonant
114B0	114BE	Vowel_Dependent
114BF	114C0	Bindu
114C1		Visarga
114C2		Virama
114C3		Nukta
114C4		Avagraha
114D0	114D9	Number
11580	1158D	Vowel_Independent
1158E	115AE	Consonant
115AF	115B5	Vowel_Dependent
115B8	115BB	Vowel_Dependent
115BC	115BD	Bindu
115BE		Visarga
115BF		Virama
115C0		Nukta
115D8	115DB	Vowel_Independent
115DC	115DD	Vowel_Dependent
11600	1160D	Vowel_Independent
1160E	1162F	Consonant
11630	1163C	Vowel_Dependent
1163D		Bindu
1163E		Visarga
1163F		Virama
11640		Vowel_Dependent
11650	11659	Number
11680	11689	Vowel_Independent
1168A	116AA	Consonant
116AB		Bindu
116AC		Visarga
116AD	116B5	Vowel_Dependent
116B6		Virama
116B7		Nukta
116B8		Consonant
116C0	116C9	Number
11700	1171A	Consonant
1171D	1171F	Consonant_Medial
11720	1172A	Vowel_Dependent
1172B		Pure_Killer
11730	1173B	Number
11740	11746	Consonant
11800	11809	Vowel_Independent
1180A	1182B	Consonant
1182C	11836	Vowel_Dependent
11837		Bindu
11838		Visarga
11839		Virama
1183A		Nukta
11900	11906	Vowel_Independent
11909		Vowel_Independent
1190C	11913	Consonant
11915	11916	Consonant
11918	1192F	Consonant
11930	11935	Vowel_Dependent
11937	11938	Vowel_Dependent
1193B	1193C	Bindu
1193D		Pure_Killer
1193E		Invisible_Stacker
1193F		Consonant_Prefixed
11940		Consonant_Medial
11941		Consonant_Preceding_Repha
11942		Consonant_Medial
11943		Nukta
11950	11959	Number
119A0	119A7	Vowel_Independent
119AA	119AD	Vowel_Independent
119AE	119D0	Consonant
119D1	119D7	Vowel_Dependent
119DA	119DD	Vowel_Dependent
119DE		Bindu
119DF		Visarga
119E0		Virama
119E1		Avagraha
119E4		Vowel_Dependent
11A00		Vowel_Independent
11A01	11A0A	Vowel_Dependent
11A0B	11A32	Consonant
11A33		Syllable_Modifier
11A34		Pure_Killer
11A35	11A38	Bindu
11A39		Visarga
11A3A		Consonant_Prefixed
11A3B	11A3E	Consonant_Medial
11A3F		Consonant_Placeholder
11A45		Consonant_Placeholder
11A47		Invisible_Stacker
11A50		Vowel_Independent
11A51	11A5B	Vowel_Dependent
11A5C	11A83	Consonant
11A84	11A89	Consonant_Prefixed
11A8A	11A95	Consonant_Final
11A96		Bindu
11A97		Visarga
11A98		Gemination_Mark
11A99		Invisible_Stacker
11A9D		Avagraha
11C00	11C08	Vowel_Independent
11C0A	11C0D	Vowel_Independent
11C0E	11C2E	Consonant
11C2F	11C36	Vowel_Dependent
11C38	11C3B	Vowel_Dependent
11C3C	11C3D	Bindu
11C3E		Visarga
11C3F		Virama
11C40		Avagraha
11C50	11C6C	Number
11C72	11C8F	Consonant
11C92	11CA7	Consonant_Subjoined
11CA9	11CAF	Consonant_Subjoined
11CB0	11CB4	Vowel_Dependent
11CB5	11CB6	Bindu
11D00	11D06	Vowel_Independent
11D08	11D09	Vowel_Independent
11D0B		Vowel_Independent
11D0C	11D30	Consonant
11D31	11D36	Vowel_Dependent
11D3A		Vowel_Dependent
11D3C	11D3D	Vowel_Dependent
11D3F		Vowel_Dependent
11D40		Bindu
11D41		Visarga
11D42		Nukta
11D43		Vowel_Dependent
11D44		Pure_Killer
11D45		Invisible_Stacker
11D46		Consonant_Preceding_Repha
11D47		Consonant_Medial
11D50	11D59	Number
11D60	11D65	Vowel_Independent
11D67	11D68	Vowel_Independent
11D6A	11D6B	Vowel_Independent
11D6C	11D89	Consonant
11D8A	11D8E	Vowel_Dependent
11D90	11D91	Vowel_Dependent
11D93	11D94	Vowel_Dependent
11D95		Bindu
11D96		Visarga
11D97		Invisible_Stacker
11DA0	11DA9	Number
11EE0	11EF1	Consonant
11EF2		Consonant_Placeholder
11EF3	11EF6	Vowel_Dependent
END
