# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 14.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.



# The name this table is to be known by, with the format of the mappings in
# the main body of the table, and what all code points missing from this file
# map to.
$Unicode::UCD::SwashInfo{'ToIdentifierType'}{'format'} = 'sw'; # string, but some elements are interpreted as a list; white space occurs only as list item separators
$Unicode::UCD::SwashInfo{'ToIdentifierType'}{'missing'} = 'Not_Character';

return <<'END';
9	D	Not_XID
20	26	Not_XID
27		Inclusion
28	2C	Not_XID
2D	2E	Inclusion
2F		Not_XID
30	39	Recommended
3A		Inclusion
3B	40	Not_XID
41	5A	Recommended
5B	5E	Not_XID
5F		Recommended
60		Not_XID
61	7A	Recommended
7B	7E	Not_XID
85		Not_XID
A0		Not_NFKC
A1	A7	Not_XID
A8		Not_NFKC
A9		Not_XID
AA		Not_NFKC
AB	AC	Not_XID
AD		Default_Ignorable
AE		Not_XID
AF		Not_NFKC
B0	B1	Not_XID
B2	B5	Not_NFKC
B6		Not_XID
B7		Inclusion
B8	BA	Not_NFKC
BB		Not_XID
BC	BE	Not_NFKC
BF		Not_XID
C0	D6	Recommended
D7		Not_XID
D8	F6	Recommended
F7		Not_XID
F8	131	Recommended
132	133	Not_NFKC
134	13E	Recommended
13F	140	Not_NFKC
141	148	Recommended
149		Deprecated
14A	17E	Recommended
17F		Not_NFKC
180		Technical
181	18C	Uncommon_Use
18D		Technical Obsolete
18E		Uncommon_Use
18F		Recommended
190	19F	Uncommon_Use
1A0	1A1	Recommended
1A2	1A9	Uncommon_Use
1AA	1AB	Technical Obsolete
1AC	1AE	Uncommon_Use
1AF	1B0	Recommended
1B1	1B8	Uncommon_Use
1B9		Obsolete
1BA	1BB	Technical Obsolete
1BC	1BD	Uncommon_Use
1BE		Technical Obsolete
1BF		Obsolete
1C0	1C3	Technical
1C4	1CC	Not_NFKC
1CD	1DC	Recommended
1DD		Uncommon_Use
1DE	1E3	Recommended
1E4	1E5	Uncommon_Use
1E6	1F0	Recommended
1F1	1F3	Not_NFKC
1F4	1F5	Recommended
1F6	1F7	Obsolete
1F8	21B	Recommended
21C	21D	Obsolete
21E	21F	Recommended
220	225	Uncommon_Use
226	233	Recommended
234	236	Technical
237	24F	Uncommon_Use
250	252	Technical
253	254	Uncommon_Use Technical
255		Technical
256	257	Uncommon_Use Technical
258		Technical
259		Recommended
25A		Technical
25B		Uncommon_Use Technical
25C	262	Technical
263		Uncommon_Use Technical
264	267	Technical
268	269	Uncommon_Use Technical
26A	271	Technical
272		Uncommon_Use Technical
273	276	Technical
277		Technical Obsolete
278	27B	Technical
27C		Technical Obsolete
27D	288	Technical
289		Uncommon_Use Technical
28A	291	Technical
292		Uncommon_Use Technical
293	29D	Technical
29E		Technical Obsolete
29F	2AF	Technical
2B0	2B8	Not_NFKC
2B9	2BA	Technical
2BB	2BC	Recommended
2BD	2C1	Technical
2C2	2C5	Not_XID
2C6	2D1	Technical
2D2	2D7	Not_XID
2D8	2DD	Not_NFKC
2DE	2DF	Not_XID
2E0	2E4	Not_NFKC
2E5	2EB	Not_XID
2EC		Recommended
2ED		Not_XID
2EE		Technical
2EF	2FF	Not_XID
300	304	Recommended
305		Uncommon_Use
306	30C	Recommended
30D		Uncommon_Use
30E		Technical
30F	311	Recommended
312		Technical
313	314	Recommended
315		Technical
316		Uncommon_Use
317	31A	Technical
31B		Recommended
31C	320	Technical
321	322	Uncommon_Use
323	328	Recommended
329	32C	Technical
32D	32E	Recommended
32F		Technical
330	331	Recommended
332		Uncommon_Use
333		Technical
334		Uncommon_Use
335		Recommended
336		Uncommon_Use
337		Technical
338	339	Recommended
33A	33F	Technical
340	341	Not_NFKC
342		Recommended
343	344	Not_NFKC
345		Recommended
346	34E	Technical
34F		Default_Ignorable
350	357	Technical
358		Uncommon_Use
359	362	Technical
363	373	Obsolete
374		Not_NFKC
375		Inclusion
376	377	Obsolete
37A		Not_NFKC
37B	37D	Recommended
37E		Not_NFKC
37F		Obsolete
384	385	Not_NFKC
386		Recommended
387		Not_NFKC
388	38A	Recommended
38C		Recommended
38E	3A1	Recommended
3A3	3CE	Recommended
3CF		Technical
3D0	3D6	Not_NFKC
3D7		Technical
3D8	3E1	Obsolete
3E2	3EF	Exclusion
3F0	3F2	Not_NFKC
3F3		Technical Obsolete
3F4	3F5	Not_NFKC
3F6		Not_XID
3F7	3F8	Obsolete
3F9		Not_NFKC
3FA	3FB	Obsolete
3FC	45F	Recommended
460	481	Obsolete
482		Obsolete Not_XID
483		Obsolete
484	487	Technical Obsolete
488	489	Obsolete Not_XID
48A	4FF	Recommended
500	50F	Obsolete
510	529	Recommended
52A	52D	Obsolete
52E	52F	Recommended
531	556	Recommended
559		Recommended
55A	55F	Not_XID
560		Technical
561	586	Recommended
587		Not_NFKC
588		Technical
589		Not_XID
58A		Inclusion
58D	58F	Not_XID
591	5A1	Uncommon_Use
5A2		Uncommon_Use Obsolete
5A3	5B3	Uncommon_Use
5B4		Recommended
5B5	5BD	Uncommon_Use
5BE		Not_XID
5BF		Uncommon_Use
5C0		Not_XID
5C1	5C2	Uncommon_Use
5C3		Not_XID
5C4		Uncommon_Use
5C5		Uncommon_Use Obsolete
5C6		Obsolete Not_XID
5C7		Uncommon_Use Technical
5D0	5EA	Recommended
5EF	5F2	Recommended
5F3	5F4	Inclusion
600	60F	Not_XID
610	61A	Uncommon_Use
61B		Not_XID
61C		Default_Ignorable
61D	61F	Not_XID
620	63F	Recommended
640		Obsolete
641	655	Recommended
656	65F	Uncommon_Use
660	669	Recommended
66A	66D	Not_XID
66E	66F	Obsolete
670	672	Recommended
673		Deprecated
674		Recommended
675	678	Not_NFKC
679	68D	Recommended
68E		Obsolete
68F	6A0	Recommended
6A1		Obsolete
6A2	6D3	Recommended
6D4		Not_XID
6D5		Recommended
6D6	6DC	Uncommon_Use
6DD	6DE	Not_XID
6DF	6E4	Uncommon_Use
6E5	6E6	Recommended
6E7	6E8	Uncommon_Use
6E9		Not_XID
6EA	6ED	Uncommon_Use
6EE	6FC	Recommended
6FD	6FE	Inclusion
6FF		Recommended
700	70D	Limited_Use Not_XID
70F		Limited_Use Not_XID
710	73F	Limited_Use
740	74A	Limited_Use Technical
74D	74F	Limited_Use
750	7B1	Recommended
7C0	7E7	Limited_Use
7E8	7EA	Limited_Use Obsolete
7EB	7F5	Limited_Use
7F6	7F9	Limited_Use Not_XID
7FA		Limited_Use Obsolete
7FD		Limited_Use
7FE	7FF	Limited_Use Not_XID
800	82D	Exclusion
830	83E	Exclusion Not_XID
840	85B	Limited_Use
85E		Limited_Use Not_XID
860	86A	Limited_Use
870	887	Recommended
888		Not_XID
889	88E	Recommended
890	891	Not_XID
898	89F	Uncommon_Use
8A0	8AC	Recommended
8AD	8B1	Obsolete
8B2		Recommended
8B3	8B4	Uncommon_Use
8B5	8C9	Recommended
8CA	8E1	Uncommon_Use
8E2		Not_XID
8E3	900	Uncommon_Use
901	94D	Recommended
94E		Obsolete
94F	950	Recommended
951	952	Obsolete
953	954	Technical
955		Uncommon_Use
956	957	Recommended
958	95F	Not_NFKC
960	963	Recommended
964	965	Not_XID
966	96F	Recommended
970		Not_XID
971	977	Recommended
978		Obsolete
979	97F	Recommended
980		Obsolete
981	983	Recommended
985	98C	Recommended
98F	990	Recommended
993	9A8	Recommended
9AA	9B0	Recommended
9B2		Recommended
9B6	9B9	Recommended
9BC	9C4	Recommended
9C7	9C8	Recommended
9CB	9CE	Recommended
9D7		Recommended
9DC	9DD	Not_NFKC
9DF		Not_NFKC
9E0	9E3	Recommended
9E6	9F1	Recommended
9F2	9FB	Not_XID
9FC		Obsolete
9FD		Not_XID
9FE		Recommended
A01	A03	Recommended
A05	A0A	Recommended
A0F	A10	Recommended
A13	A28	Recommended
A2A	A30	Recommended
A32		Recommended
A33		Not_NFKC
A35		Recommended
A36		Not_NFKC
A38	A39	Recommended
A3C		Recommended
A3E	A42	Recommended
A47	A48	Recommended
A4B	A4D	Recommended
A51		Uncommon_Use
A59	A5B	Not_NFKC
A5C		Recommended
A5E		Not_NFKC
A66	A74	Recommended
A75		Uncommon_Use
A76		Not_XID
A81	A83	Recommended
A85	A8D	Recommended
A8F	A91	Recommended
A93	AA8	Recommended
AAA	AB0	Recommended
AB2	AB3	Recommended
AB5	AB9	Recommended
ABC	AC5	Recommended
AC7	AC9	Recommended
ACB	ACD	Recommended
AD0		Recommended
AE0	AE3	Recommended
AE6	AEF	Recommended
AF0	AF1	Not_XID
AF9		Uncommon_Use
AFA	AFF	Recommended
B01	B03	Recommended
B05	B0C	Recommended
B0F	B10	Recommended
B13	B28	Recommended
B2A	B30	Recommended
B32	B33	Recommended
B35	B39	Recommended
B3C	B43	Recommended
B44		Uncommon_Use
B47	B48	Recommended
B4B	B4D	Recommended
B55	B57	Recommended
B5C	B5D	Not_NFKC
B5F	B61	Recommended
B62	B63	Uncommon_Use
B66	B6F	Recommended
B70		Not_XID
B71		Recommended
B72	B77	Not_XID
B82	B83	Recommended
B85	B8A	Recommended
B8E	B90	Recommended
B92	B95	Recommended
B99	B9A	Recommended
B9C		Recommended
B9E	B9F	Recommended
BA3	BA4	Recommended
BA8	BAA	Recommended
BAE	BB9	Recommended
BBE	BC2	Recommended
BC6	BC8	Recommended
BCA	BCD	Recommended
BD0		Recommended
BD7		Recommended
BE6	BEF	Recommended
BF0	BFA	Not_XID
C00		Obsolete
C01	C0C	Recommended
C0E	C10	Recommended
C12	C28	Recommended
C2A	C33	Recommended
C34		Obsolete
C35	C39	Recommended
C3C	C44	Recommended
C46	C48	Recommended
C4A	C4D	Recommended
C55	C56	Recommended
C58	C59	Obsolete
C5A		Uncommon_Use
C5D		Recommended
C60	C61	Recommended
C62	C63	Uncommon_Use
C66	C6F	Recommended
C77	C7F	Not_XID
C80		Recommended
C81		Obsolete
C82	C83	Recommended
C84		Not_XID
C85	C8C	Recommended
C8E	C90	Recommended
C92	CA8	Recommended
CAA	CB3	Recommended
CB5	CB9	Recommended
CBC	CC4	Recommended
CC6	CC8	Recommended
CCA	CCD	Recommended
CD5	CD6	Recommended
CDD		Recommended
CDE		Obsolete
CE0	CE3	Recommended
CE6	CEF	Recommended
CF1	CF2	Recommended
D00		Recommended
D01		Obsolete
D02	D03	Recommended
D04		Technical Obsolete
D05	D0C	Recommended
D0E	D10	Recommended
D12	D3A	Recommended
D3B	D3C	Obsolete
D3D	D43	Recommended
D44		Uncommon_Use
D46	D48	Recommended
D4A	D4E	Recommended
D4F		Not_XID
D54	D57	Recommended
D58	D5E	Not_XID
D5F		Obsolete
D60	D61	Recommended
D62	D63	Uncommon_Use
D66	D6F	Recommended
D70	D79	Not_XID
D7A	D7F	Recommended
D81		Technical
D82	D83	Recommended
D85	D8E	Recommended
D8F	D90	Uncommon_Use Technical
D91	D96	Recommended
D9A	DA5	Recommended
DA6		Uncommon_Use Technical
DA7	DB1	Recommended
DB3	DBB	Recommended
DBD		Recommended
DC0	DC6	Recommended
DCA		Recommended
DCF	DD4	Recommended
DD6		Recommended
DD8	DDE	Recommended
DDF		Uncommon_Use Technical
DE6	DEF	Obsolete
DF2		Recommended
DF3		Uncommon_Use Technical
DF4		Not_XID
E01	E32	Recommended
E33		Not_NFKC
E34	E3A	Recommended
E3F		Not_XID
E40	E4E	Recommended
E4F		Not_XID
E50	E59	Recommended
E5A	E5B	Not_XID
E81	E82	Recommended
E84		Recommended
E86	E8A	Recommended
E8C	EA3	Recommended
EA5		Recommended
EA7	EB2	Recommended
EB3		Not_NFKC
EB4	EBD	Recommended
EC0	EC4	Recommended
EC6		Recommended
EC8	ECD	Recommended
ED0	ED9	Recommended
EDC	EDD	Not_NFKC
EDE	EDF	Recommended
F00		Recommended
F01	F0A	Not_XID
F0B		Inclusion
F0C		Not_NFKC
F0D	F17	Not_XID
F18	F19	Technical
F1A	F1F	Not_XID
F20	F29	Recommended
F2A	F34	Not_XID
F35		Recommended
F36		Not_XID
F37		Recommended
F38		Not_XID
F39		Uncommon_Use
F3A	F3D	Not_XID
F3E	F42	Recommended
F43		Not_NFKC
F44	F47	Recommended
F49	F4C	Recommended
F4D		Not_NFKC
F4E	F51	Recommended
F52		Not_NFKC
F53	F56	Recommended
F57		Not_NFKC
F58	F5B	Recommended
F5C		Not_NFKC
F5D	F68	Recommended
F69		Not_NFKC
F6A	F6C	Recommended
F71	F72	Recommended
F73		Not_NFKC
F74		Recommended
F75	F76	Not_NFKC
F77		Deprecated
F78		Not_NFKC
F79		Deprecated
F7A	F80	Recommended
F81		Not_NFKC
F82	F84	Recommended
F85		Not_XID
F86	F92	Recommended
F93		Not_NFKC
F94	F97	Recommended
F99	F9C	Recommended
F9D		Not_NFKC
F9E	FA1	Recommended
FA2		Not_NFKC
FA3	FA6	Recommended
FA7		Not_NFKC
FA8	FAB	Recommended
FAC		Not_NFKC
FAD	FB8	Recommended
FB9		Not_NFKC
FBA	FBC	Recommended
FBE	FC5	Not_XID
FC6		Recommended
FC7	FCC	Not_XID
FCE	FDA	Not_XID
1000	1049	Recommended
104A	104F	Not_XID
1050	109D	Recommended
109E	109F	Not_XID
10A0	10C5	Obsolete
10C7		Recommended
10CD		Recommended
10D0	10F0	Recommended
10F1	10F6	Obsolete
10F7	10FA	Recommended
10FB		Not_XID
10FC		Not_NFKC
10FD	10FF	Recommended
1100	115E	Obsolete
115F	1160	Default_Ignorable
1161	11FF	Obsolete
1200	1248	Recommended
124A	124D	Recommended
1250	1256	Recommended
1258		Recommended
125A	125D	Recommended
1260	1288	Recommended
128A	128D	Recommended
1290	12B0	Recommended
12B2	12B5	Recommended
12B8	12BE	Recommended
12C0		Recommended
12C2	12C5	Recommended
12C8	12D6	Recommended
12D8	1310	Recommended
1312	1315	Recommended
1318	135A	Recommended
135D	135F	Recommended
1360	1368	Not_XID
1369	1371	Obsolete
1372	137C	Not_XID
1380	138F	Recommended
1390	1399	Not_XID
13A0	13F5	Limited_Use
13F8	13FD	Limited_Use
1400		Limited_Use Not_XID
1401	166C	Limited_Use
166D	166E	Limited_Use Not_XID
166F	167F	Limited_Use
1680		Exclusion Not_XID
1681	169A	Exclusion
169B	169C	Exclusion Not_XID
16A0	16EA	Exclusion
16EB	16ED	Not_XID
16EE	16F8	Exclusion
1700	1715	Exclusion
171F	1734	Exclusion
1735	1736	Exclusion Not_XID
1740	1753	Exclusion
1760	176C	Exclusion
176E	1770	Exclusion
1772	1773	Exclusion
1780	17A2	Recommended
17A3	17A4	Deprecated
17A5	17A7	Recommended
17A8		Obsolete
17A9	17B3	Recommended
17B4	17B5	Default_Ignorable
17B6	17CD	Recommended
17CE	17CF	Technical
17D0		Recommended
17D1		Technical Obsolete
17D2		Recommended
17D3		Obsolete
17D4	17D6	Not_XID
17D7		Recommended
17D8		Obsolete Not_XID
17D9	17DB	Not_XID
17DC		Recommended
17DD		Technical Obsolete
17E0	17E9	Recommended
17F0	17F9	Not_XID
1800	180A	Exclusion Not_XID
180B	180F	Default_Ignorable
1810	1819	Exclusion
1820	1878	Exclusion
1880	18A8	Exclusion
18A9		Uncommon_Use Exclusion
18AA		Exclusion
18B0	18F5	Limited_Use
1900	191E	Limited_Use
1920	192B	Limited_Use
1930	193B	Limited_Use
1940		Limited_Use Not_XID
1944	1945	Limited_Use Not_XID
1946	196D	Limited_Use
1970	1974	Limited_Use
1980	19AB	Limited_Use
19B0	19C9	Limited_Use
19D0	19DA	Limited_Use
19DE	19DF	Limited_Use Not_XID
19E0	19FF	Not_XID
1A00	1A1B	Exclusion
1A1E	1A1F	Exclusion Not_XID
1A20	1A5E	Limited_Use
1A60	1A7C	Limited_Use
1A7F	1A89	Limited_Use
1A90	1A99	Limited_Use
1AA0	1AA6	Limited_Use Not_XID
1AA7		Limited_Use
1AA8	1AAD	Limited_Use Not_XID
1AB0	1ABD	Obsolete
1ABE		Not_XID
1ABF	1AC0	Technical
1AC1	1ACE	Uncommon_Use
1B00	1B4C	Limited_Use
1B50	1B59	Limited_Use
1B5A	1B6A	Limited_Use Not_XID
1B6B	1B73	Limited_Use Technical
1B74	1B7E	Limited_Use Not_XID
1B80	1BF3	Limited_Use
1BFC	1BFF	Limited_Use Not_XID
1C00	1C37	Limited_Use
1C3B	1C3F	Limited_Use Not_XID
1C40	1C49	Limited_Use
1C4D	1C7D	Limited_Use
1C7E	1C7F	Limited_Use Not_XID
1C80	1C88	Obsolete
1C90	1CBA	Recommended
1CBD	1CBF	Recommended
1CC0	1CC7	Limited_Use Not_XID
1CD0	1CD2	Obsolete
1CD3		Obsolete Not_XID
1CD4	1CF9	Obsolete
1CFA		Exclusion
1D00	1D2B	Technical
1D2C	1D2E	Not_NFKC
1D2F		Technical
1D30	1D3A	Not_NFKC
1D3B		Technical
1D3C	1D4D	Not_NFKC
1D4E		Technical
1D4F	1D6A	Not_NFKC
1D6B	1D77	Technical
1D78		Not_NFKC
1D79	1D9A	Technical
1D9B	1DBF	Not_NFKC
1DC0	1DC3	Technical Obsolete
1DC4	1DCD	Technical
1DCE		Technical Obsolete
1DCF	1DD0	Technical
1DD1	1DE6	Technical Obsolete
1DE7	1DF9	Technical
1DFA		Limited_Use Technical
1DFB	1DFF	Technical
1E00	1E99	Recommended
1E9A	1E9B	Not_NFKC
1E9C	1E9D	Technical
1E9E		Recommended
1E9F		Technical
1EA0	1EF9	Recommended
1EFA	1EFF	Technical
1F00	1F15	Recommended
1F18	1F1D	Recommended
1F20	1F45	Recommended
1F48	1F4D	Recommended
1F50	1F57	Recommended
1F59		Recommended
1F5B		Recommended
1F5D		Recommended
1F5F	1F70	Recommended
1F71		Not_NFKC
1F72		Recommended
1F73		Not_NFKC
1F74		Recommended
1F75		Not_NFKC
1F76		Recommended
1F77		Not_NFKC
1F78		Recommended
1F79		Not_NFKC
1F7A		Recommended
1F7B		Not_NFKC
1F7C		Recommended
1F7D		Not_NFKC
1F80	1FB4	Recommended
1FB6	1FBA	Recommended
1FBB		Not_NFKC
1FBC		Recommended
1FBD	1FC1	Not_NFKC
1FC2	1FC4	Recommended
1FC6	1FC8	Recommended
1FC9		Not_NFKC
1FCA		Recommended
1FCB		Not_NFKC
1FCC		Recommended
1FCD	1FCF	Not_NFKC
1FD0	1FD2	Recommended
1FD3		Not_NFKC
1FD6	1FDA	Recommended
1FDB		Not_NFKC
1FDD	1FDF	Not_NFKC
1FE0	1FE2	Recommended
1FE3		Not_NFKC
1FE4	1FEA	Recommended
1FEB		Not_NFKC
1FEC		Recommended
1FED	1FEF	Not_NFKC
1FF2	1FF4	Recommended
1FF6	1FF8	Recommended
1FF9		Not_NFKC
1FFA		Recommended
1FFB		Not_NFKC
1FFC		Recommended
1FFD	1FFE	Not_NFKC
2000	200A	Not_NFKC
200B		Default_Ignorable
200C	200D	Inclusion
200E	200F	Default_Ignorable
2010		Inclusion
2011		Not_NFKC
2012	2016	Not_XID
2017		Not_NFKC
2018		Not_XID
2019		Inclusion
201A	2023	Not_XID
2024	2026	Not_NFKC
2027		Inclusion
2028	2029	Not_XID
202A	202E	Default_Ignorable
202F		Not_NFKC
2030	2032	Not_XID
2033	2034	Not_NFKC
2035		Not_XID
2036	2037	Not_NFKC
2038	203B	Not_XID
203C		Not_NFKC
203D		Not_XID
203E		Not_NFKC
203F	2040	Technical
2041	2046	Not_XID
2047	2049	Not_NFKC
204A	2053	Not_XID
2054		Uncommon_Use
2055		Not_XID
2056		Obsolete Not_XID
2057		Not_NFKC
2058	205E	Obsolete Not_XID
205F		Not_NFKC
2060	2064	Default_Ignorable
2066	2069	Default_Ignorable
206A	206F	Deprecated
2070	2071	Not_NFKC
2074	208E	Not_NFKC
2090	209C	Not_NFKC
20A0	20A7	Not_XID
20A8		Not_NFKC
20A9	20C0	Not_XID
20D0	20DC	Technical
20DD	20E0	Technical Not_XID
20E1		Technical
20E2	20E4	Technical Not_XID
20E5	20F0	Technical
2100	2103	Not_NFKC
2104		Not_XID
2105	2107	Not_NFKC
2108		Not_XID
2109	2113	Not_NFKC
2114		Not_XID
2115	2116	Not_NFKC
2117		Not_XID
2118		Technical
2119	211D	Not_NFKC
211E	211F	Not_XID
2120	2122	Not_NFKC
2123		Not_XID
2124		Not_NFKC
2125		Not_XID
2126		Not_NFKC
2127		Obsolete Not_XID
2128		Not_NFKC
2129		Not_XID
212A	212D	Not_NFKC
212E		Technical
212F	2131	Not_NFKC
2132		Obsolete
2133	2139	Not_NFKC
213A		Not_XID
213B	2140	Not_NFKC
2141	2144	Not_XID
2145	2149	Not_NFKC
214A	214D	Not_XID
214E		Obsolete
214F		Obsolete Not_XID
2150	217F	Not_NFKC
2180	2183	Technical Obsolete
2184	2188	Obsolete
2189		Not_NFKC
218A	218B	Uncommon_Use Not_XID
2190	222B	Not_XID
222C	222D	Not_NFKC
222E		Not_XID
222F	2230	Not_NFKC
2231	2328	Not_XID
2329	232A	Deprecated
232B	2426	Not_XID
2440	244A	Not_XID
2460	24EA	Not_NFKC
24EB	24FF	Technical Not_XID
2500	27FF	Not_XID
2800	28FF	Technical Not_XID
2900	2A0B	Not_XID
2A0C		Not_NFKC
2A0D	2A73	Not_XID
2A74	2A76	Not_NFKC
2A77	2ADB	Not_XID
2ADC		Not_NFKC
2ADD	2B73	Not_XID
2B76	2B95	Not_XID
2B97	2BEB	Not_XID
2BEC	2BEF	Uncommon_Use Not_XID
2BF0	2BFF	Not_XID
2C00	2C5F	Exclusion
2C60	2C67	Technical
2C68	2C6C	Uncommon_Use
2C6D	2C76	Obsolete
2C77	2C7B	Technical
2C7C	2C7D	Not_NFKC
2C7E	2C7F	Obsolete
2C80	2CE4	Exclusion
2CE5	2CEA	Exclusion Not_XID
2CEB	2CEF	Exclusion
2CF0	2CF1	Technical Exclusion
2CF2	2CF3	Exclusion
2CF9	2CFF	Exclusion Not_XID
2D00	2D25	Obsolete
2D27		Recommended
2D2D		Recommended
2D30	2D67	Limited_Use
2D6F		Not_NFKC
2D70		Limited_Use Not_XID
2D7F		Limited_Use
2D80	2D96	Recommended
2DA0	2DA6	Recommended
2DA8	2DAE	Recommended
2DB0	2DB6	Recommended
2DB8	2DBE	Recommended
2DC0	2DC6	Recommended
2DC8	2DCE	Recommended
2DD0	2DD6	Recommended
2DD8	2DDE	Recommended
2DE0	2DFF	Obsolete
2E00	2E0D	Technical Obsolete Not_XID
2E0E	2E16	Obsolete Not_XID
2E17	2E29	Not_XID
2E2A	2E32	Obsolete Not_XID
2E33	2E34	Not_XID
2E35		Obsolete Not_XID
2E36	2E38	Not_XID
2E39		Obsolete Not_XID
2E3A	2E5D	Not_XID
2E80	2E99	Not_XID
2E9B	2E9E	Not_XID
2E9F		Not_NFKC
2EA0	2EF2	Not_XID
2EF3		Not_NFKC
2F00	2FD5	Not_NFKC
2FF0	2FFB	Not_XID
3000		Not_NFKC
3001	3004	Not_XID
3005	3007	Recommended
3008	301D	Not_XID
301E		Obsolete Not_XID
301F	3020	Not_XID
3021	302D	Technical
302E	302F	Technical Obsolete
3030		Not_XID
3031	3035	Technical
3036		Not_NFKC
3037		Not_XID
3038	303A	Not_NFKC
303B	303C	Technical
303D	303F	Not_XID
3041	3096	Recommended
3099	309A	Recommended
309B	309C	Not_NFKC
309D	309E	Recommended
309F		Not_NFKC
30A0		Inclusion
30A1	30FA	Recommended
30FB		Inclusion
30FC	30FE	Recommended
30FF		Not_NFKC
3105	312D	Recommended
312E		Obsolete
312F		Recommended
3131	3163	Not_NFKC
3164		Default_Ignorable
3165	318E	Not_NFKC
3190	3191	Not_XID
3192	319F	Not_NFKC
31A0	31BF	Recommended
31C0	31E3	Not_XID
31F0	31FF	Obsolete
3200	321E	Not_NFKC
3220	3247	Not_NFKC
3248	324F	Not_XID
3250	327E	Not_NFKC
327F		Technical Not_XID
3280	33FF	Not_NFKC
3400	4DBF	Recommended
4DC0	4DFF	Technical Not_XID
4E00	9FFF	Recommended
A000	A48C	Limited_Use
A490	A4C6	Limited_Use Not_XID
A4D0	A4FD	Limited_Use
A4FE	A4FF	Limited_Use Not_XID
A500	A60C	Limited_Use
A60D	A60F	Limited_Use Not_XID
A610	A612	Limited_Use Obsolete
A613	A629	Limited_Use
A62A	A62B	Limited_Use Obsolete
A640	A66E	Obsolete
A66F		Uncommon_Use
A670	A673	Obsolete Not_XID
A674	A67B	Obsolete
A67C	A67D	Uncommon_Use
A67E		Not_XID
A67F		Recommended
A680	A69B	Obsolete
A69C	A69D	Not_NFKC
A69E		Uncommon_Use Obsolete
A69F		Obsolete
A6A0	A6F1	Limited_Use
A6F2	A6F7	Limited_Use Not_XID
A700	A707	Obsolete Not_XID
A708	A716	Technical Not_XID
A717	A71F	Recommended
A720	A721	Not_XID
A722	A72F	Technical Obsolete
A730	A76F	Obsolete
A770		Not_NFKC
A771	A787	Obsolete
A788		Recommended
A789	A78A	Not_XID
A78B	A78C	Uncommon_Use
A78D		Recommended
A78E		Technical
A78F		Uncommon_Use
A790	A791	Obsolete
A792	A793	Recommended
A794	A7A9	Obsolete
A7AA		Recommended
A7AB	A7AD	Obsolete
A7AE		Recommended
A7AF		Technical
A7B0	A7B1	Obsolete
A7B2	A7B7	Uncommon_Use
A7B8	A7B9	Recommended
A7BA	A7BF	Technical
A7C0	A7CA	Recommended
A7D0	A7D1	Recommended
A7D3		Recommended
A7D5	A7D9	Recommended
A7F2	A7F4	Not_NFKC
A7F5	A7F7	Obsolete
A7F8	A7F9	Not_NFKC
A7FA		Technical
A7FB	A7FF	Obsolete
A800	A827	Limited_Use
A828	A82B	Limited_Use Not_XID
A82C		Limited_Use
A830	A839	Not_XID
A840	A873	Exclusion
A874	A877	Exclusion Not_XID
A880	A8C5	Limited_Use
A8CE	A8CF	Limited_Use Not_XID
A8D0	A8D9	Limited_Use
A8E0	A8F7	Obsolete
A8F8	A8FA	Obsolete Not_XID
A8FB		Obsolete
A8FC		Uncommon_Use Obsolete Not_XID
A8FD		Uncommon_Use Obsolete
A8FE	A8FF	Obsolete
A900	A92D	Limited_Use
A92E		Not_XID
A92F		Limited_Use Not_XID
A930	A953	Exclusion
A95F		Exclusion Not_XID
A960	A97C	Obsolete
A980	A9C0	Limited_Use
A9C1	A9CD	Limited_Use Not_XID
A9CF		Limited_Use Exclusion
A9D0	A9D9	Limited_Use
A9DE	A9DF	Limited_Use Not_XID
A9E0	A9E6	Obsolete
A9E7	A9FE	Recommended
AA00	AA36	Limited_Use
AA40	AA4D	Limited_Use
AA50	AA59	Limited_Use
AA5C	AA5F	Limited_Use Not_XID
AA60	AA76	Recommended
AA77	AA79	Not_XID
AA7A	AA7F	Recommended
AA80	AAC2	Limited_Use
AADB	AADD	Limited_Use
AADE	AADF	Limited_Use Not_XID
AAE0	AAEF	Limited_Use
AAF0	AAF1	Limited_Use Not_XID
AAF2	AAF6	Limited_Use
AB01	AB06	Recommended
AB09	AB0E	Recommended
AB11	AB16	Recommended
AB20	AB26	Recommended
AB28	AB2E	Recommended
AB30	AB5A	Obsolete
AB5B		Not_XID
AB5C	AB5F	Not_NFKC
AB60	AB63	Uncommon_Use
AB64	AB65	Obsolete
AB66	AB67	Recommended
AB68		Technical
AB69		Not_NFKC
AB6A	AB6B	Not_XID
AB70	ABEA	Limited_Use
ABEB		Limited_Use Not_XID
ABEC	ABED	Limited_Use
ABF0	ABF9	Limited_Use
AC00	D7A3	Recommended
D7B0	D7C6	Obsolete
D7CB	D7FB	Obsolete
F900	FA0D	Not_NFKC
FA0E	FA0F	Recommended
FA10		Not_NFKC
FA11		Recommended
FA12		Not_NFKC
FA13	FA14	Recommended
FA15	FA1E	Not_NFKC
FA1F		Recommended
FA20		Not_NFKC
FA21		Recommended
FA22		Not_NFKC
FA23	FA24	Recommended
FA25	FA26	Not_NFKC
FA27	FA29	Recommended
FA2A	FA6D	Not_NFKC
FA70	FAD9	Not_NFKC
FB00	FB06	Not_NFKC
FB13	FB17	Not_NFKC
FB1D		Not_NFKC
FB1E		Uncommon_Use Technical
FB1F	FB36	Not_NFKC
FB38	FB3C	Not_NFKC
FB3E		Not_NFKC
FB40	FB41	Not_NFKC
FB43	FB44	Not_NFKC
FB46	FBB1	Not_NFKC
FBB2	FBC2	Technical Not_XID
FBD3	FD3D	Not_NFKC
FD3E	FD4F	Technical Not_XID
FD50	FD8F	Not_NFKC
FD92	FDC7	Not_NFKC
FDCF		Technical Not_XID
FDF0	FDFC	Not_NFKC
FDFD	FDFF	Technical Not_XID
FE00	FE0F	Default_Ignorable
FE10	FE19	Not_NFKC
FE20	FE2D	Technical
FE2E	FE2F	Uncommon_Use Technical
FE30	FE44	Not_NFKC
FE45	FE46	Technical Not_XID
FE47	FE52	Not_NFKC
FE54	FE66	Not_NFKC
FE68	FE6B	Not_NFKC
FE70	FE72	Not_NFKC
FE73		Technical
FE74		Not_NFKC
FE76	FEFC	Not_NFKC
FEFF		Default_Ignorable
FF01	FF9F	Not_NFKC
FFA0		Default_Ignorable
FFA1	FFBE	Not_NFKC
FFC2	FFC7	Not_NFKC
FFCA	FFCF	Not_NFKC
FFD2	FFD7	Not_NFKC
FFDA	FFDC	Not_NFKC
FFE0	FFE6	Not_NFKC
FFE8	FFEE	Not_NFKC
FFF9	FFFD	Not_XID
10000	1000B	Exclusion
1000D	10026	Exclusion
10028	1003A	Exclusion
1003C	1003D	Exclusion
1003F	1004D	Exclusion
10050	1005D	Exclusion
10080	100FA	Exclusion
10100	10102	Exclusion Not_XID
10107	10133	Exclusion Not_XID
10137	1013F	Exclusion Not_XID
10140	10174	Obsolete
10175	1018E	Not_XID
10190	1019C	Not_XID
101A0		Not_XID
101D0	101FC	Obsolete Not_XID
101FD		Obsolete
10280	1029C	Exclusion
102A0	102D0	Exclusion
102E0		Obsolete
102E1	102FB	Obsolete Not_XID
10300	1031F	Exclusion
10320	10323	Exclusion Not_XID
1032D	1034A	Exclusion
10350	1037A	Exclusion
10380	1039D	Exclusion
1039F		Exclusion Not_XID
103A0	103C3	Exclusion
103C8	103CF	Exclusion
103D0		Exclusion Not_XID
103D1	103D5	Exclusion
10400	1049D	Exclusion
104A0	104A9	Exclusion
104B0	104D3	Limited_Use
104D8	104FB	Limited_Use
10500	10527	Exclusion
10530	10563	Exclusion
1056F		Exclusion Not_XID
10570	1057A	Exclusion
1057C	1058A	Exclusion
1058C	10592	Exclusion
10594	10595	Exclusion
10597	105A1	Exclusion
105A3	105B1	Exclusion
105B3	105B9	Exclusion
105BB	105BC	Exclusion
10600	10736	Exclusion
10740	10755	Exclusion
10760	10767	Exclusion
10780		Uncommon_Use
10781	10785	Not_NFKC
10787	107B0	Not_NFKC
107B2	107BA	Not_NFKC
10800	10805	Exclusion
10808		Exclusion
1080A	10835	Exclusion
10837	10838	Exclusion
1083C		Exclusion
1083F	10855	Exclusion
10857	1085F	Exclusion Not_XID
10860	10876	Exclusion
10877	1087F	Exclusion Not_XID
10880	1089E	Exclusion
108A7	108AF	Exclusion Not_XID
108E0	108F2	Exclusion
108F4	108F5	Exclusion
108FB	108FF	Exclusion Not_XID
10900	10915	Exclusion
10916	1091B	Exclusion Not_XID
1091F		Exclusion Not_XID
10920	10939	Exclusion
1093F		Exclusion Not_XID
10980	109B7	Exclusion
109BC	109BD	Exclusion Not_XID
109BE	109BF	Exclusion
109C0	109CF	Exclusion Not_XID
109D2	109FF	Exclusion Not_XID
10A00	10A03	Exclusion
10A05	10A06	Exclusion
10A0C	10A13	Exclusion
10A15	10A17	Exclusion
10A19	10A35	Exclusion
10A38	10A3A	Exclusion
10A3F		Exclusion
10A40	10A48	Exclusion Not_XID
10A50	10A58	Exclusion Not_XID
10A60	10A7C	Exclusion
10A7D	10A7F	Exclusion Not_XID
10A80	10A9C	Exclusion
10A9D	10A9F	Exclusion Not_XID
10AC0	10AC7	Exclusion
10AC8		Exclusion Not_XID
10AC9	10AE6	Exclusion
10AEB	10AF6	Exclusion Not_XID
10B00	10B35	Exclusion
10B39	10B3F	Exclusion Not_XID
10B40	10B55	Exclusion
10B58	10B5F	Exclusion Not_XID
10B60	10B72	Exclusion
10B78	10B7F	Exclusion Not_XID
10B80	10B91	Exclusion
10B99	10B9C	Exclusion Not_XID
10BA9	10BAF	Exclusion Not_XID
10C00	10C48	Exclusion
10C80	10CB2	Exclusion
10CC0	10CF2	Exclusion
10CFA	10CFF	Exclusion Not_XID
10D00	10D27	Limited_Use
10D30	10D39	Limited_Use
10E60	10E7E	Not_XID
10E80	10EA9	Exclusion
10EAB	10EAC	Exclusion
10EAD		Exclusion Not_XID
10EB0	10EB1	Exclusion
10F00	10F1C	Exclusion
10F1D	10F26	Exclusion Not_XID
10F27		Exclusion
10F30	10F50	Exclusion
10F51	10F59	Exclusion Not_XID
10F70	10F85	Exclusion
10F86	10F89	Exclusion Not_XID
10FB0	10FC4	Exclusion
10FC5	10FCB	Exclusion Not_XID
10FE0	10FF6	Exclusion
11000	11046	Exclusion
11047	1104D	Exclusion Not_XID
11052	11065	Exclusion Not_XID
11066	11075	Exclusion
1107F	110BA	Exclusion
110BB	110C1	Exclusion Not_XID
110C2		Exclusion
110CD		Exclusion Not_XID
110D0	110E8	Exclusion
110F0	110F9	Exclusion
11100	11134	Limited_Use
11136	1113F	Limited_Use
11140	11143	Limited_Use Not_XID
11144	11147	Limited_Use
11150	11173	Exclusion
11174	11175	Exclusion Not_XID
11176		Exclusion
11180	111C4	Exclusion
111C5	111C8	Exclusion Not_XID
111C9	111CC	Exclusion
111CD		Exclusion Not_XID
111CE	111DA	Exclusion
111DB		Exclusion Not_XID
111DC		Exclusion
111DD	111DF	Exclusion Not_XID
111E1	111F4	Not_XID
11200	11211	Exclusion
11213	11237	Exclusion
11238	1123D	Exclusion Not_XID
1123E		Exclusion
11280	11286	Exclusion
11288		Exclusion
1128A	1128D	Exclusion
1128F	1129D	Exclusion
1129F	112A8	Exclusion
112A9		Exclusion Not_XID
112B0	112EA	Exclusion
112F0	112F9	Exclusion
11300		Exclusion
11301		Recommended
11302		Exclusion
11303		Recommended
11305	1130C	Exclusion
1130F	11310	Exclusion
11313	11328	Exclusion
1132A	11330	Exclusion
11332	11333	Exclusion
11335	11339	Exclusion
1133B	1133C	Recommended
1133D	11344	Exclusion
11347	11348	Exclusion
1134B	1134D	Exclusion
11350		Exclusion
11357		Exclusion
1135D	11363	Exclusion
11366	1136C	Exclusion
11370	11374	Exclusion
11400	1144A	Limited_Use
1144B	1144F	Limited_Use Not_XID
11450	11459	Limited_Use
1145A	1145B	Limited_Use Not_XID
1145D		Limited_Use Not_XID
1145E	11461	Limited_Use
11480	114C5	Exclusion
114C6		Exclusion Not_XID
114C7		Exclusion
114D0	114D9	Exclusion
11580	115B5	Exclusion
115B8	115C0	Exclusion
115C1	115D7	Exclusion Not_XID
115D8	115DD	Exclusion
11600	11640	Exclusion
11641	11643	Exclusion Not_XID
11644		Exclusion
11650	11659	Exclusion
11660	1166C	Exclusion Not_XID
11680	116B8	Exclusion
116B9		Exclusion Not_XID
116C0	116C9	Exclusion
11700	1171A	Exclusion
1171D	1172B	Exclusion
11730	11739	Exclusion
1173A	1173F	Exclusion Not_XID
11740	11746	Exclusion
11800	1183A	Exclusion
1183B		Exclusion Not_XID
118A0	118E9	Exclusion
118EA	118F2	Exclusion Not_XID
118FF	11906	Exclusion
11909		Exclusion
1190C	11913	Exclusion
11915	11916	Exclusion
11918	11935	Exclusion
11937	11938	Exclusion
1193B	11943	Exclusion
11944	11946	Exclusion Not_XID
11950	11959	Exclusion
119A0	119A7	Exclusion
119AA	119D7	Exclusion
119DA	119E1	Exclusion
119E2		Exclusion Not_XID
119E3	119E4	Exclusion
11A00	11A3E	Exclusion
11A3F	11A46	Exclusion Not_XID
11A47		Exclusion
11A50	11A99	Exclusion
11A9A	11A9C	Exclusion Not_XID
11A9D		Exclusion
11A9E	11AA2	Exclusion Not_XID
11AB0	11ABF	Limited_Use
11AC0	11AF8	Exclusion
11C00	11C08	Exclusion
11C0A	11C36	Exclusion
11C38	11C40	Exclusion
11C41	11C45	Exclusion Not_XID
11C50	11C59	Exclusion
11C5A	11C6C	Exclusion Not_XID
11C70	11C71	Exclusion Not_XID
11C72	11C8F	Exclusion
11C92	11CA7	Exclusion
11CA9	11CB6	Exclusion
11D00	11D06	Exclusion
11D08	11D09	Exclusion
11D0B	11D36	Exclusion
11D3A		Exclusion
11D3C	11D3D	Exclusion
11D3F	11D47	Exclusion
11D50	11D59	Exclusion
11D60	11D65	Limited_Use
11D67	11D68	Limited_Use
11D6A	11D8E	Limited_Use
11D90	11D91	Limited_Use
11D93	11D98	Limited_Use
11DA0	11DA9	Limited_Use
11EE0	11EF6	Exclusion
11EF7	11EF8	Exclusion Not_XID
11FB0		Limited_Use
11FC0	11FF1	Not_XID
11FFF		Not_XID
12000	12399	Exclusion
12400	1246E	Exclusion
12470	12474	Exclusion Not_XID
12480	12543	Exclusion
12F90	12FF0	Exclusion
12FF1	12FF2	Exclusion Not_XID
13000	1342E	Exclusion
13430	13438	Exclusion Not_XID
14400	14646	Exclusion
16800	16A38	Limited_Use
16A40	16A5E	Uncommon_Use Exclusion
16A60	16A69	Uncommon_Use Exclusion
16A6E	16A6F	Exclusion Not_XID
16A70	16ABE	Exclusion
16AC0	16AC9	Exclusion
16AD0	16AED	Exclusion
16AF0	16AF4	Exclusion
16AF5		Exclusion Not_XID
16B00	16B36	Exclusion
16B37	16B3F	Exclusion Not_XID
16B40	16B43	Exclusion
16B44	16B45	Exclusion Not_XID
16B50	16B59	Exclusion
16B5B	16B61	Exclusion Not_XID
16B63	16B77	Exclusion
16B7D	16B8F	Exclusion
16E40	16E7F	Exclusion
16E80	16E9A	Exclusion Not_XID
16F00	16F4A	Limited_Use
16F4F	16F87	Limited_Use
16F8F	16F9F	Limited_Use
16FE0	16FE1	Exclusion
16FE2		Not_XID
16FE3		Obsolete
16FE4		Exclusion
16FF0	16FF1	Recommended
17000	187F7	Exclusion
18800	18CD5	Exclusion
18D00	18D08	Exclusion
1AFF0	1AFF3	Uncommon_Use
1AFF5	1AFFB	Uncommon_Use
1AFFD	1AFFE	Uncommon_Use
1B000	1B11E	Obsolete
1B11F	1B122	Recommended
1B150	1B152	Recommended
1B164	1B167	Recommended
1B170	1B2FB	Exclusion
1BC00	1BC6A	Exclusion
1BC70	1BC7C	Exclusion
1BC80	1BC88	Exclusion
1BC90	1BC99	Exclusion
1BC9C		Exclusion Not_XID
1BC9D	1BC9E	Exclusion
1BC9F		Exclusion Not_XID
1BCA0	1BCA3	Default_Ignorable
1CF00	1CF2D	Technical
1CF30	1CF46	Technical
1CF50	1CFC3	Technical Not_XID
1D000	1D0F5	Technical Not_XID
1D100	1D126	Technical Not_XID
1D129	1D15D	Technical Not_XID
1D15E	1D164	Not_NFKC
1D165	1D169	Technical
1D16A	1D16C	Technical Not_XID
1D16D	1D172	Technical
1D173	1D17A	Default_Ignorable
1D17B	1D182	Technical
1D183	1D184	Technical Not_XID
1D185	1D18B	Technical
1D18C	1D1A9	Technical Not_XID
1D1AA	1D1AD	Technical
1D1AE	1D1BA	Technical Not_XID
1D1BB	1D1C0	Not_NFKC
1D1C1	1D1DD	Technical Not_XID
1D1DE	1D1E8	Uncommon_Use Technical Not_XID
1D1E9	1D1EA	Technical Not_XID
1D200	1D241	Obsolete Not_XID
1D242	1D244	Technical Obsolete
1D245		Obsolete Not_XID
1D2E0	1D2F3	Not_XID
1D300	1D356	Technical Not_XID
1D360	1D378	Not_XID
1D400	1D454	Not_NFKC
1D456	1D49C	Not_NFKC
1D49E	1D49F	Not_NFKC
1D4A2		Not_NFKC
1D4A5	1D4A6	Not_NFKC
1D4A9	1D4AC	Not_NFKC
1D4AE	1D4B9	Not_NFKC
1D4BB		Not_NFKC
1D4BD	1D4C3	Not_NFKC
1D4C5	1D505	Not_NFKC
1D507	1D50A	Not_NFKC
1D50D	1D514	Not_NFKC
1D516	1D51C	Not_NFKC
1D51E	1D539	Not_NFKC
1D53B	1D53E	Not_NFKC
1D540	1D544	Not_NFKC
1D546		Not_NFKC
1D54A	1D550	Not_NFKC
1D552	1D6A5	Not_NFKC
1D6A8	1D7CB	Not_NFKC
1D7CE	1D7FF	Not_NFKC
1D800	1D9FF	Exclusion Not_XID
1DA00	1DA36	Exclusion
1DA37	1DA3A	Exclusion Not_XID
1DA3B	1DA6C	Exclusion
1DA6D	1DA74	Exclusion Not_XID
1DA75		Exclusion
1DA76	1DA83	Exclusion Not_XID
1DA84		Exclusion
1DA85	1DA8B	Exclusion Not_XID
1DA9B	1DA9F	Exclusion
1DAA1	1DAAF	Exclusion
1DF00	1DF1E	Recommended
1E000	1E006	Exclusion
1E008	1E018	Exclusion
1E01B	1E021	Exclusion
1E023	1E024	Exclusion
1E026	1E02A	Exclusion
1E100	1E12C	Limited_Use
1E130	1E13D	Limited_Use
1E140	1E149	Limited_Use
1E14E		Limited_Use
1E14F		Limited_Use Not_XID
1E290	1E2AE	Exclusion
1E2C0	1E2F9	Limited_Use
1E2FF		Limited_Use Not_XID
1E7E0	1E7E6	Recommended
1E7E8	1E7EB	Recommended
1E7ED	1E7EE	Recommended
1E7F0	1E7FE	Recommended
1E800	1E8C4	Exclusion
1E8C7	1E8CF	Exclusion Not_XID
1E8D0	1E8D6	Exclusion
1E900	1E94B	Limited_Use
1E950	1E959	Limited_Use
1E95E	1E95F	Limited_Use Not_XID
1EC71	1ECB4	Not_XID
1ED01	1ED3D	Not_XID
1EE00	1EE03	Not_NFKC
1EE05	1EE1F	Not_NFKC
1EE21	1EE22	Not_NFKC
1EE24		Not_NFKC
1EE27		Not_NFKC
1EE29	1EE32	Not_NFKC
1EE34	1EE37	Not_NFKC
1EE39		Not_NFKC
1EE3B		Not_NFKC
1EE42		Not_NFKC
1EE47		Not_NFKC
1EE49		Not_NFKC
1EE4B		Not_NFKC
1EE4D	1EE4F	Not_NFKC
1EE51	1EE52	Not_NFKC
1EE54		Not_NFKC
1EE57		Not_NFKC
1EE59		Not_NFKC
1EE5B		Not_NFKC
1EE5D		Not_NFKC
1EE5F		Not_NFKC
1EE61	1EE62	Not_NFKC
1EE64		Not_NFKC
1EE67	1EE6A	Not_NFKC
1EE6C	1EE72	Not_NFKC
1EE74	1EE77	Not_NFKC
1EE79	1EE7C	Not_NFKC
1EE7E		Not_NFKC
1EE80	1EE89	Not_NFKC
1EE8B	1EE9B	Not_NFKC
1EEA1	1EEA3	Not_NFKC
1EEA5	1EEA9	Not_NFKC
1EEAB	1EEBB	Not_NFKC
1EEF0	1EEF1	Not_XID
1F000	1F02B	Not_XID
1F030	1F093	Not_XID
1F0A0	1F0AE	Not_XID
1F0B1	1F0BF	Not_XID
1F0C1	1F0CF	Not_XID
1F0D1	1F0F5	Not_XID
1F100	1F10A	Not_NFKC
1F10B	1F10F	Not_XID
1F110	1F12E	Not_NFKC
1F12F		Not_XID
1F130	1F14F	Not_NFKC
1F150	1F169	Not_XID
1F16A	1F16C	Not_NFKC
1F16D	1F18F	Not_XID
1F190		Not_NFKC
1F191	1F1AD	Not_XID
1F1E6	1F1FF	Not_XID
1F200	1F202	Not_NFKC
1F210	1F23B	Not_NFKC
1F240	1F248	Not_NFKC
1F250	1F251	Not_NFKC
1F260	1F265	Not_XID
1F300	1F54E	Not_XID
1F54F		Uncommon_Use Not_XID
1F550	1F6D7	Not_XID
1F6DD	1F6EC	Not_XID
1F6F0	1F6FC	Not_XID
1F700	1F773	Not_XID
1F780	1F7D8	Not_XID
1F7E0	1F7EB	Not_XID
1F7F0		Not_XID
1F800	1F80B	Not_XID
1F810	1F847	Not_XID
1F850	1F859	Not_XID
1F860	1F887	Not_XID
1F890	1F8AD	Not_XID
1F8B0	1F8B1	Not_XID
1F900	1FA53	Not_XID
1FA60	1FA6D	Not_XID
1FA70	1FA74	Not_XID
1FA78	1FA7C	Not_XID
1FA80	1FA86	Not_XID
1FA90	1FAAC	Not_XID
1FAB0	1FABA	Not_XID
1FAC0	1FAC5	Not_XID
1FAD0	1FAD9	Not_XID
1FAE0	1FAE7	Not_XID
1FAF0	1FAF6	Not_XID
1FB00	1FB92	Not_XID
1FB94	1FBCA	Not_XID
1FBF0	1FBF9	Not_NFKC
20000	2A6DF	Recommended
2A700	2B738	Recommended
2B740	2B81D	Recommended
2B820	2CEA1	Recommended
2CEB0	2EBE0	Recommended
2F800	2FA1D	Not_NFKC
30000	3134A	Recommended
E0001		Deprecated
E0020	E007F	Default_Ignorable
E0100	E01EF	Default_Ignorable
END
