# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 14.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V34
2365
2366
2493
2494
2749
2750
2877
2878
3133
3134
3261
3262
3389
3390
3973
3974
6108
6109
7098
7099
70081
70082
70461
70462
70727
70728
70852
70853
72161
72162
72349
72350
72768
72769
END
